| Title: | PAVER: Pathway Analysis Visualization with Embedding Representations |
|---|---|
| Description: | Summary visualization using embedding representations to reveal underlying themes within sets of pathway terms. |
| Authors: | William G Ryan V [aut, cre] (ORCID: <https://orcid.org/0000-0003-4868-4002>) |
| Maintainer: | William G Ryan V <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-14 06:13:53 UTC |
| Source: | https://github.com/CogDisResLab/PAVER |
This function computes the cosine dissimilarity matrix based on the input matrix. The cosine dissimilarity between two vectors is defined as 1 minus the cosine similarity.
cosine_dissimilarity(mat, root = FALSE)cosine_dissimilarity(mat, root = FALSE)
mat |
A numeric matrix or data frame. |
root |
A logical value indicating whether to take the square root of the cosine dissimilarity matrix. Default is FALSE. |
A dissimilarity matrix of class "dist" containing the cosine dissimilarity between each pair of rows.
TRUETRUE
This function clusters pathway embeddings using cosine similarity and generates themes for the clusters.
generate_themes(PAVER_result, hclust_method = "ward.D2", ...)generate_themes(PAVER_result, hclust_method = "ward.D2", ...)
PAVER_result |
A list containing the result of running prepare_data |
hclust_method |
The agglomeration method to be used in hierarchical clustering. Default is "ward.D2". |
... |
Additional arguments to be passed to dynamicTreeCut |
A list containing the updated PAVER_result
TRUETRUE
A wide data frame with Normalized Enrichment Scores from Gene-Set Enrichment Analysis of three different comparisons.
gsea_examplegsea_example
A data frame with 1080 rows and 4 columns:
Gene Ontology Term IDs
NES of GO terms
NES of GO terms
NES of GO terms
https://doi.org/10.1038/s41380-021-01205-y
A wide data frame with enrichment scores (log10 FDR) from MetaboAnalyst of one comparison.
kegg_examplekegg_example
A data frame with 183 rows and 2 columns:
KEGG Pathway IDS
Enrichment Scores of KEGG pathways
https://doi.org/10.1101/2023.10.13.562226
This function takes a PAVER result object and generates a combined ggplot2 figure consisting of the PAVER_cluster_plot, PAVER_regulation_plot, PAVER_interpretation_plot, and PAVER_hunter_plot.
PAVER_combined_plot(PAVER_result, unit = NULL)PAVER_combined_plot(PAVER_result, unit = NULL)
PAVER_result |
a list containing the output of PAVER analysis |
unit |
optionally, the unit of enrichment analysis for the figure legend title. |
A combined ggplot2 figure consisting of the PAVER_cluster_plot, PAVER_regulation_plot, PAVER_interpretation_plot, and PAVER_hunter_plot.
TRUETRUE
This function takes a PAVER result object and prepares it for export as a wide format data frame. The resulting data frame will have GO Term IDs, Definitions, generated themes, and columns for each of the groups in the PAVER result, with values representing the original input value of each GO term for that group.
PAVER_export(PAVER_result)PAVER_export(PAVER_result)
PAVER_result |
A PAVER result object generated by the |
A wide format data frame with GO Term IDs, Definitions, generated themes, and columns for each of the groups in the PAVER result, with values representing the original input value of each GO term for that group.
TRUETRUE
This function takes a PAVER result object and generates a heatmap of the enrichment analysis with clustering and color-coded values based on the direction of regulation.
PAVER_hunter_plot(PAVER_result, unit = NULL, show_row_titles = TRUE)PAVER_hunter_plot(PAVER_result, unit = NULL, show_row_titles = TRUE)
PAVER_result |
a list containing the output of PAVER analysis |
unit |
optionally, the unit of enrichment analysis for the figure legend title. |
show_row_titles |
a logical indicating whether to show row titles in the heatmap. |
A heatmap of the expression data with clustering and color-coded values based on the direction of regulation.
TRUETRUE
This function takes a PAVER result object and generates a ggplot2 scatterplot of the MDS layout with labeled points colored by group.
PAVER_interpretation_plot(PAVER_result)PAVER_interpretation_plot(PAVER_result)
PAVER_result |
a list containing the output of PAVER analysis |
A ggplot2 scatterplot of the MDS layout with labeled points colored by group.
TRUETRUE
This function takes a PAVER result object and generates a ggplot2 scatterplot of the UMAP layout colored by direction of regulation (up or down) for each group.
PAVER_regulation_plot(PAVER_result)PAVER_regulation_plot(PAVER_result)
PAVER_result |
a list containing the output of PAVER analysis |
A ggplot2 scatterplot of the UMAP layout colored by direction of regulation (up or down) and faceted for each group.
TRUETRUE
This function takes a PAVER result object and generates a ggplot2 scatterplot of the UMAP layout colored by cluster assignments.
PAVER_theme_plot(PAVER_result, show_cluster_legend = TRUE)PAVER_theme_plot(PAVER_result, show_cluster_legend = TRUE)
PAVER_result |
a list containing the output of PAVER analysis |
show_cluster_legend |
a logical indicating whether to show the cluster legend. |
A ggplot2 scatterplot of the UMAP layout colored by cluster assignments
TRUETRUE
This function prepares the results of pathway analysis for downstream theme generation and visualization using precomputed embeddings.
prepare_data(input, embeddings, term2name)prepare_data(input, embeddings, term2name)
input |
A data frame in wide format containing the pathway analysis results. The first column is expected to be term IDs, e.g. GO:0000001, while the remaining columns are expected to be numeric values representing the enrichment of each term in each group. |
embeddings |
A matrix containing the precomputed embeddings of the input terms. |
term2name |
A data frame containing two columns that map pathway term IDs to pathway term names. |
A PAVER_result list with the prepared data ready for theme generation
TRUETRUE